@@ -43,33 +43,7 @@ Outputs:
     gentcst.log
 
 """
-import csv
-import json
-import os
-import re
-from copy import deepcopy
-from os import getcwd
-from os.path import basename
-from os.path import dirname
-from os.path import exists
-from os.path import splitext
-
-import numpy as np
-import sh
-import yaml
-from docopt import docopt
-
-import sonusai
-from sonusai import SonusAIError
-from sonusai import create_file_handler
-from sonusai import initial_log_messages
 from sonusai import logger
-from sonusai import update_console_handler
-from sonusai.mixture import get_default_config
-from sonusai.mixture import raw_load_config
-from sonusai.mixture import update_config_from_hierarchy
-from sonusai.mixture import update_truth_settings
-from sonusai.utils import trim_docstring
 
 CONFIG_FILE = 'config.yml'
 
@@ -79,6 +53,20 @@ def gentcst(fold: str = '*',
             hierarchical: bool = False,
             update: bool = False,
             verbose: bool = False) -> (dict, dict):
+    import os
+    from copy import deepcopy
+    from os.path import dirname
+    from os.path import exists
+    from os.path import splitext
+
+    from sonusai import SonusAIError
+    from sonusai import initial_log_messages
+    from sonusai import update_console_handler
+    from sonusai.mixture import get_default_config
+    from sonusai.mixture import raw_load_config
+    from sonusai.mixture import update_config_from_hierarchy
+    from sonusai.mixture import update_truth_settings
+
     update_console_handler(verbose)
     initial_log_messages('gentcst')
 
@@ -136,11 +124,8 @@ def gentcst(fold: str = '*',
                 if key != 'truth_settings':
                     local_config[key] = specific_config[key]
                 else:
-                    if not isinstance(specific_config['truth_settings'], list):
-                        specific_config['truth_settings'] = [specific_config['truth_settings']]
-                    update_truth_settings(given=specific_config['truth_settings'],
-                                          default=local_config['truth_settings'])
-                    local_config['truth_settings'] = specific_config['truth_settings']
+                    local_config['truth_settings'] = update_truth_settings(given=specific_config['truth_settings'],
+                                                                           default=local_config['truth_settings'])
 
         truth_settings = deepcopy(local_config['truth_settings'])
         for idx, val in enumerate(truth_settings):
@@ -150,7 +135,7 @@ def gentcst(fold: str = '*',
                     del val[key]
 
         target = {
-            'target_name':    file['file'],
+            'name':           file['file'],
             'truth_settings': truth_settings
         }
 
@@ -163,6 +148,9 @@ def gentcst(fold: str = '*',
 
 
 def get_ontology(ontology: str) -> list:
+    import json
+    from os.path import exists
+
     ontology_data = []
 
     if exists(ontology):
@@ -182,6 +170,8 @@ def get_ontology(ontology: str) -> list:
 
 
 def get_dirs() -> list:
+    import sh
+
     match = sh.find('.', '-type', 'd')
     match = list(map(str.strip, match))
 
@@ -202,6 +192,10 @@ def get_leaf_from_classes(classes: list) -> str:
 
 
 def get_all_files(hierarchical: bool) -> list:
+    import re
+
+    import sh
+
     match = sh.find('.', '-regex', '.*/[0-9]+-.*\.txt')
     match = list(map(str.strip, match))
 
@@ -231,6 +225,8 @@ def get_all_files(hierarchical: bool) -> list:
 
 
 def get_use_folds(all_folds: list, fold: str) -> list:
+    import numpy as np
+
     req_folds = get_req_folds(all_folds, fold)
     use_folds = list(set(req_folds).intersection(all_folds))
 
@@ -262,6 +258,8 @@ def get_item_from_id(ontology_data: list, identity: str) -> dict:
 
 
 def get_name_from_id(ontology_data: list, identity: str) -> list:
+    from sonusai import SonusAIError
+
     name = None
     found = False
 
@@ -277,6 +275,8 @@ def get_name_from_id(ontology_data: list, identity: str) -> list:
 
 
 def get_id_from_name(ontology_data: list, name: str) -> str:
+    from sonusai import SonusAIError
+
     identity = None
     found = False
 
@@ -371,7 +371,7 @@ def get_labels_from_files(files: list) -> list:
     all_labels = [file['labels'] for file in files]
 
     # Get labels by depth
-    labels_by_depth = [[] for n in range(max([len(label) for label in all_labels]))]
+    labels_by_depth = [[] for _ in range(max([len(label) for label in all_labels]))]
     for label in all_labels:
         for index, name in enumerate(label):
             labels_by_depth[index].append(name)
@@ -407,6 +407,11 @@ def get_index_from_label(labels: list, label: str) -> int:
 
 
 def get_config() -> dict:
+    from os.path import exists
+
+    from sonusai import SonusAIError
+    from sonusai.mixture import raw_load_config
+
     if not exists(CONFIG_FILE):
         raise SonusAIError(f'No {CONFIG_FILE} at top level')
 
@@ -428,6 +433,8 @@ def get_config() -> dict:
 
 
 def validate_ontology(ontology: str, files: list) -> list:
+    from os.path import exists
+
     if exists(ontology):
         ontology_data = get_ontology(ontology)
         logger.debug(f'Reference ontology in {ontology} has {len(ontology_data)} classes')
@@ -471,6 +478,10 @@ def get_node_from_name(ontology_data: list, name: str) -> dict:
 
 
 def write_metadata_to_tree(ontology_data: list, file: dict):
+    import json
+    from os.path import basename
+    from os.path import dirname
+
     if ontology_data:
         node = get_node_from_name(ontology_data, file['classes'][-1])
         if node:
@@ -505,46 +516,57 @@ def report_leaf_fold_data_usage(all_files: list, use_files: list):
 
 
 def main():
-    try:
-        args = docopt(trim_docstring(__doc__), version=sonusai.__version__, options_first=True)
+    import csv
+    from os import getcwd
+    from os.path import basename
+    from os.path import splitext
 
-        verbose = args['--verbose']
-        output_name = args['--output']
-        fold = args['--fold']
-        ontology = args['--ontology']
-        hierarchical = args['--hierarchical']
-        update = args['--update']
+    import yaml
+    from docopt import docopt
 
-        if not output_name:
-            output_name = basename(getcwd()) + '.yml'
+    import sonusai
+    from sonusai import create_file_handler
+    from sonusai.utils import trim_docstring
 
-        log_name = 'gentcst.log'
+    args = docopt(trim_docstring(__doc__), version=sonusai.__version__, options_first=True)
 
-        create_file_handler(log_name)
+    verbose = args['--verbose']
+    output_name = args['--output']
+    fold = args['--fold']
+    ontology = args['--ontology']
+    hierarchical = args['--hierarchical']
+    update = args['--update']
 
-        config, labels = gentcst(fold=fold,
-                                 ontology=ontology,
-                                 hierarchical=hierarchical,
-                                 update=update,
-                                 verbose=verbose)
+    if not output_name:
+        output_name = basename(getcwd()) + '.yml'
 
-        with open(file=output_name, mode='w') as f:
-            yaml.dump(config, f)
-            logger.info(f'Wrote config to {output_name}')
+    log_name = 'gentcst.log'
 
-        csv_fields = ['index', 'display_name']
-        csv_name = splitext(output_name)[0] + '.csv'
+    create_file_handler(log_name)
 
-        with open(file=csv_name, mode='w') as f:
-            writer = csv.DictWriter(f, fieldnames=csv_fields)
-            writer.writeheader()
-            writer.writerows(labels)
-            logger.info(f'Wrote labels to {csv_name}')
+    config, labels = gentcst(fold=fold,
+                             ontology=ontology,
+                             hierarchical=hierarchical,
+                             update=update,
+                             verbose=verbose)
 
-    except KeyboardInterrupt:
-        logger.info('Canceled due to keyboard interrupt')
-        raise SystemExit(0)
+    with open(file=output_name, mode='w') as f:
+        yaml.dump(config, f)
+        logger.info(f'Wrote config to {output_name}')
+
+    csv_fields = ['index', 'display_name']
+    csv_name = splitext(output_name)[0] + '.csv'
+
+    with open(file=csv_name, mode='w') as f:
+        writer = csv.DictWriter(f, fieldnames=csv_fields)
+        writer.writeheader()
+        writer.writerows(labels)
+        logger.info(f'Wrote labels to {csv_name}')
 
 
 if __name__ == '__main__':
-    main()
+    try:
+        main()
+    except KeyboardInterrupt:
+        logger.info('Canceled due to keyboard interrupt')
+        raise SystemExit(0)
