@@ -4,17 +4,17 @@ from typing import Union
 import numpy as np
 import pandas as pd
 
-from sonusai.metrics.one_hot import one_hot
-from sonusai.mixture.get_mixid_data import get_mixid_data
+from sonusai.mixture.mixdb import MixtureDatabase
+from sonusai.mixture.mixdb import MixtureID
 
 
-def class_summary(mixdb: dict,
-                  mixid: Union[str, List[int]],
-                  truth_f,
-                  predict,
-                  pred_thr=0,
-                  truth_thr=0.5,
-                  timesteps=0):
+def class_summary(mixdb: MixtureDatabase,
+                  mixid: MixtureID,
+                  truth_f: np.ndarray,
+                  predict: np.ndarray,
+                  pred_thr: Union[float, List[float]] = 0,
+                  truth_thr: float = 0.5,
+                  timesteps: int = 0) -> pd.DataFrame:
     """ Calculate table of metrics per class, and averages for a list
         of mixtures using truth and prediction data features x num_classes
         Example:
@@ -29,21 +29,14 @@ def class_summary(mixdb: dict,
           macro avg     0.85    0.83    0.84    0.05    0.96            3768
           micro-avgwo
     """
+    from sonusai.metrics import one_hot
+    from sonusai.mixture import get_mixid_data
+
     num_classes = truth_f.shape[1]
 
-    ytrue, ypred = get_mixid_data(mixdb, mixid, truth_f, predict)
-    # file_frame_segments = get_file_frame_segments(mixdb, mixid)
-    # total_frames = sum([file_frame_segments[m].length for m in file_frame_segments])
-    # ytrue = np.empty((total_frames, num_classes), dtype=np.single)
-    # ypred = np.empty((total_frames, num_classes), dtype=np.single)
-    # start = 0
-    # for m in file_frame_segments:
-    #     length = file_frame_segments[m].length
-    #     ytrue[start:start + length] = truth_f[file_frame_segments[m].get_slice()]
-    #     ypred[start:start + length] = predict[file_frame_segments[m].get_slice()]
-    #     start += length
+    y_truth_f, y_predict = get_mixid_data(mixdb, mixid, truth_f, predict)
 
-    if not mixdb['truth_mutex'] and num_classes > 1:
+    if not mixdb.truth_mutex and num_classes > 1:
         if np.ndim(pred_thr) == 0 and pred_thr == 0:
             pred_thr = 0.5
 
@@ -51,26 +44,26 @@ def class_summary(mixdb: dict,
             if pred_thr[0] == 0:
                 pred_thr = 0.5
 
-    _, metrics, _, _, _, metavg = one_hot(ytrue, ypred, pred_thr, truth_thr, timesteps)
+    _, metrics, _, _, _, metavg = one_hot(y_truth_f, y_predict, pred_thr, truth_thr, timesteps)
 
     # [ACC, TPR, PPV, TNR, FPR, HITFA, F1, MCC, NT, PT, TP, FP, AP, AUC]
-    tableidx = np.array([2, 1, 6, 4, 12, 13, 0, 9])
+    table_idx = np.array([2, 1, 6, 4, 0, 12, 13, 9])
     col_n = ['PPV', 'TPR', 'F1', 'FPR', 'ACC', 'AP', 'AUC', 'Support']
-    if mixdb['truth_mutex']:
-        if len(mixdb['class_labels']) >= num_classes - 1:  # labels exist with or wo Other
-            row_n = mixdb['class_labels']
-            if len(mixdb['class_labels']) == num_classes - 1:  # Other label does not exist, so add it
+    if mixdb.truth_mutex:
+        if len(mixdb.class_labels) >= num_classes - 1:  # labels exist with or without Other
+            row_n = mixdb.class_labels
+            if len(mixdb.class_labels) == num_classes - 1:  # Other label does not exist, so add it
                 row_n.append('Other')
         else:
             row_n = ([f'Class {i}' for i in range(1, num_classes)])
             row_n.append('Other')
     else:
-        if len(mixdb['class_labels']) == num_classes:
-            row_n = mixdb['class_labels']
+        if len(mixdb.class_labels) == num_classes:
+            row_n = mixdb.class_labels
         else:
             row_n = ([f'Class {i}' for i in range(1, num_classes + 1)])
 
-    df = pd.DataFrame(metrics[:, tableidx], columns=col_n, index=row_n)
+    df = pd.DataFrame(metrics[:, table_idx], columns=col_n, index=row_n)
 
     # [miPPV, miTPR, miF1, miFPR, miACC, miAP, miAUC, TPSUM]
     avg_row_n = ['Macro-avg', 'Micro-avg', 'Weighted-avg']
