@@ -1,47 +1,72 @@
 from typing import Any
 from typing import Callable
+from typing import Dict
 from typing import List
-from typing import Union
+
+from sonusai.mixture.mixdb import MixtureDatabase
+from sonusai.mixture.mixdb import MixtureID
 
 
-def get_mixids_from_mixture_field_predicate(mixdb: dict,
+def get_mixids_from_mixture_field_predicate(mixdb: MixtureDatabase,
                                             field: str,
-                                            mixid: Union[str, List[int]] = None,
-                                            predicate: Callable[[Any], bool] = None) -> dict:
+                                            mixid: MixtureID = None,
+                                            predicate: Callable[[Any], bool] = None) -> Dict[int, List[int]]:
     """
     Generate mixture IDs based on mixture field and predicate
     Return a dictionary where:
         - keys are the matching field values
         - values are lists of the mixids that match the criteria
     """
+    from typing import Any
+
     from sonusai.mixture import convert_mixid_to_list
 
     mixid_out = convert_mixid_to_list(mixdb, mixid)
 
     if predicate is None:
-        def predicate(x: Any) -> bool:
+        def predicate(_: Any) -> bool:
             return True
 
-    criteria = sorted(
-        list(set([x[field] for i, x in enumerate(mixdb['mixtures']) if predicate(x[field]) and i in mixid_out])))
+    criteria = set()
+    for i, x in enumerate(mixdb.mixtures):
+        if i in mixid_out:
+            value = getattr(x, field)
+            if isinstance(value, list):
+                for v in value:
+                    if predicate(v):
+                        criteria.add(v)
+            elif predicate(value):
+                criteria.add(value)
+    criteria = sorted(list(criteria))
 
     result = dict()
     for criterion in criteria:
-        result[criterion] = [i for i, x in enumerate(mixdb['mixtures']) if x[field] == criterion and i in mixid_out]
+        result[criterion] = list()
+        for i, x in enumerate(mixdb.mixtures):
+            if i in mixid_out:
+                value = getattr(x, field)
+                if isinstance(value, list):
+                    for v in value:
+                        if v == criterion:
+                            result[criterion].append(i)
+                elif value == criterion:
+                    result[criterion].append(i)
 
     return result
 
 
-def get_mixids_from_truth_settings_field_predicate(mixdb: dict,
+def get_mixids_from_truth_settings_field_predicate(mixdb: MixtureDatabase,
                                                    field: str,
-                                                   mixid: Union[str, List[int]] = None,
-                                                   predicate: Callable[[Any], bool] = None) -> dict:
+                                                   mixid: MixtureID = None,
+                                                   predicate: Callable[[Any], bool] = None) -> Dict[int, List[int]]:
     """
     Generate mixture IDs based on target truth_settings field and predicate
     Return a dictionary where:
         - keys are the matching field values
         - values are lists of the mixids that match the criteria
     """
+    from typing import Any
+
     from sonusai.mixture import convert_mixid_to_list
 
     mixid_out = convert_mixid_to_list(mixdb, mixid)
@@ -50,7 +75,7 @@ def get_mixids_from_truth_settings_field_predicate(mixdb: dict,
     values = get_all_truth_settings_values_from_field(mixdb, field)
 
     if predicate is None:
-        def predicate(x: Any) -> bool:
+        def predicate(_: Any) -> bool:
             return True
 
     # Get only values of interest
@@ -60,16 +85,16 @@ def get_mixids_from_truth_settings_field_predicate(mixdb: dict,
     for value in values:
         # Get a list of targets for each field value
         indices = list()
-        for i, target in enumerate(mixdb['targets']):
-            for truth_setting in target['truth_settings']:
-                if value in truth_setting[field]:
+        for i, target in enumerate(mixdb.targets):
+            for truth_setting in target.truth_settings:
+                if value in getattr(truth_setting, field):
                     indices.append(i)
         indices = sorted(list(set(indices)))
 
         mixids = list()
         for index in indices:
-            mixids.extend([i for i, x in enumerate(mixdb['mixtures']) if
-                           x['target_file_index'] == index and i in mixid_out])
+            mixids.extend([i for i, x in enumerate(mixdb.mixtures) if
+                           index in x.target_file_index and i in mixid_out])
 
         mixids = sorted(list(set(mixids)))
         if mixids:
@@ -78,14 +103,14 @@ def get_mixids_from_truth_settings_field_predicate(mixdb: dict,
     return result
 
 
-def get_all_truth_settings_values_from_field(mixdb: dict, field: str) -> list:
+def get_all_truth_settings_values_from_field(mixdb: MixtureDatabase, field: str) -> list:
     """
     Generate a list of all values corresponding to the given field in truth_settings
     """
     result = list()
-    for target in mixdb['targets']:
-        for truth_setting in target['truth_settings']:
-            value = truth_setting[field]
+    for target in mixdb.targets:
+        for truth_setting in target.truth_settings:
+            value = getattr(truth_setting, field)
             if isinstance(value, str):
                 value = [value]
             result.extend(value)
@@ -93,9 +118,9 @@ def get_all_truth_settings_values_from_field(mixdb: dict, field: str) -> list:
     return sorted(list(set(result)))
 
 
-def get_mixids_from_noise(mixdb: dict,
-                          mixid: Union[str, List[int]] = None,
-                          predicate: Callable[[Any], bool] = None) -> dict:
+def get_mixids_from_noise(mixdb: MixtureDatabase,
+                          mixid: MixtureID = None,
+                          predicate: Callable[[Any], bool] = None) -> Dict[int, List[int]]:
     """
     Generate mixids based on noise index predicate
     Return a dictionary where:
@@ -108,9 +133,9 @@ def get_mixids_from_noise(mixdb: dict,
                                                    predicate=predicate)
 
 
-def get_mixids_from_noise_augmentation(mixdb: dict,
-                                       mixid: Union[str, List[int]] = None,
-                                       predicate: Callable[[Any], bool] = None) -> dict:
+def get_mixids_from_noise_augmentation(mixdb: MixtureDatabase,
+                                       mixid: MixtureID = None,
+                                       predicate: Callable[[Any], bool] = None) -> Dict[int, List[int]]:
     """
     Generate mixids based on a noise augmentation index predicate
     Return a dictionary where:
@@ -123,9 +148,9 @@ def get_mixids_from_noise_augmentation(mixdb: dict,
                                                    predicate=predicate)
 
 
-def get_mixids_from_target(mixdb: dict,
-                           mixid: Union[str, List[int]] = None,
-                           predicate: Callable[[Any], bool] = None) -> dict:
+def get_mixids_from_target(mixdb: MixtureDatabase,
+                           mixid: MixtureID = None,
+                           predicate: Callable[[Any], bool] = None) -> Dict[int, List[int]]:
     """
     Generate mixids based on a target index predicate
     Return a dictionary where:
@@ -138,9 +163,9 @@ def get_mixids_from_target(mixdb: dict,
                                                    predicate=predicate)
 
 
-def get_mixids_from_target_augmentation(mixdb: dict,
-                                        mixid: Union[str, List[int]] = None,
-                                        predicate: Callable[[Any], bool] = None) -> dict:
+def get_mixids_from_target_augmentation(mixdb: MixtureDatabase,
+                                        mixid: MixtureID = None,
+                                        predicate: Callable[[Any], bool] = None) -> Dict[int, List[int]]:
     """
     Generate mixids based on a target augmentation index predicate
     Return a dictionary where:
@@ -153,24 +178,26 @@ def get_mixids_from_target_augmentation(mixdb: dict,
                                                    predicate=predicate)
 
 
-def get_mixids_from_snr(mixdb: dict,
-                        mixid: Union[str, List[int]] = None,
-                        predicate: Callable[[Any], bool] = None) -> dict:
+def get_mixids_from_snr(mixdb: MixtureDatabase,
+                        mixid: MixtureID = None,
+                        predicate: Callable[[Any], bool] = None) -> Dict[float, List[int]]:
     """
     Generate mixids based on an SNR predicate
     Return a dictionary where:
         - keys are the SNRs
         - values are lists of the mixids that match the SNR
     """
+    from typing import Any
+
     from sonusai.mixture import convert_mixid_to_list
 
     mixid_out = convert_mixid_to_list(mixdb, mixid)
 
     # Get all the SNRs
-    snrs = mixdb['noise_mix']['snrs']
+    snrs = mixdb.snrs
 
     if predicate is None:
-        def predicate(x: Any) -> bool:
+        def predicate(_: Any) -> bool:
             return True
 
     # Get only the SNRs of interest (filter on predicate)
@@ -179,14 +206,14 @@ def get_mixids_from_snr(mixdb: dict,
     result = dict()
     for snr in snrs:
         # Get a list of mixids for each SNR
-        result[snr] = sorted([i for i, x in enumerate(mixdb['mixtures']) if x['snr'] == snr and i in mixid_out])
+        result[snr] = sorted([i for i, x in enumerate(mixdb.mixtures) if x.snr == snr and i in mixid_out])
 
     return result
 
 
-def get_mixids_from_truth_index(mixdb: dict,
-                                mixid: Union[str, List[int]] = None,
-                                predicate: Callable[[Any], bool] = None) -> dict:
+def get_mixids_from_truth_index(mixdb: MixtureDatabase,
+                                mixid: MixtureID = None,
+                                predicate: Callable[[Any], bool] = None) -> Dict[int, List[int]]:
     """
     Generate mixids based on a truth index predicate
     Return a dictionary where:
@@ -199,9 +226,9 @@ def get_mixids_from_truth_index(mixdb: dict,
                                                           predicate=predicate)
 
 
-def get_mixids_from_truth_function(mixdb: dict,
-                                   mixid: Union[str, List[int]] = None,
-                                   predicate: Callable[[Any], bool] = None) -> dict:
+def get_mixids_from_truth_function(mixdb: MixtureDatabase,
+                                   mixid: MixtureID = None,
+                                   predicate: Callable[[Any], bool] = None) -> Dict[int, List[int]]:
     """
     Generate mixids based on a truth function predicate
     Return a dictionary where:
