@@ -1,22 +1,31 @@
 # SonusAI general utilities
 
-from sonusai.utils.expandvars import expandvars
+from sonusai.utils.calculate_input_shape import calculate_input_shape
+from sonusai.utils.dataclass_from_dict import dataclass_from_dict
+from sonusai.utils.dbfs import dbfs_to_sample
+from sonusai.utils.dbfs import sample_to_dbfs
+from sonusai.utils.engineering_number import EngineeringNumber
+from sonusai.utils.get_label_names import get_label_names
 from sonusai.utils.grouper import grouper
 from sonusai.utils.human_readable_size import human_readable_size
+from sonusai.utils.import_keras_model import import_keras_model
 from sonusai.utils.int16_to_float import int16_to_float
 from sonusai.utils.onnx_utils import add_sonusai_metadata
 from sonusai.utils.onnx_utils import create_onnx_from_keras
 from sonusai.utils.onnx_utils import replace_stateful_grus
+from sonusai.utils.parallel import initialize_map_func
 from sonusai.utils.parallel import p_map
 from sonusai.utils.parallel import p_umap
 from sonusai.utils.parallel_tqdm import p_tqdm_map
 from sonusai.utils.parallel_tqdm import p_tqdm_umap
-from sonusai.utils.read_feature_data import read_feature_data
+from sonusai.utils.print_mixture_details import print_class_count
+from sonusai.utils.print_mixture_details import print_mixture_details
 from sonusai.utils.read_mixture_data import read_mixture_data
 from sonusai.utils.read_predict_data import read_predict_data
 from sonusai.utils.reshape import reshape_inputs
 from sonusai.utils.reshape import reshape_truth_predict
 from sonusai.utils.seconds_to_hms import seconds_to_hms
+from sonusai.utils.stratified_shuffle_split import stratified_shuffle_split_mixid
 from sonusai.utils.to_numpy_array import to_numpy_array
 from sonusai.utils.trim_docstring import trim_docstring
 from sonusai.utils.yes_or_no import yes_or_no
